//
//  JPPaymentMethodsHeaderView.h
//  JudoKit_iOS
//
//  Copyright (c) 2019 Alternative Payments Ltd
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.

#import "JPPBBAButton.h"
#import "JPApplePayButton.h"
#import <UIKit/UIKit.h>

@class JPPaymentMethodsHeaderModel, JPTransactionButton, JPUIConfiguration;

@interface JPPaymentMethodsHeaderView : UIView

/**
 * The Pay button that triggers the payment flow
 */
@property (nonatomic, strong) JPTransactionButton *payButton;

/**
 * The Apple Pay branded button that triggers the Apple Pay flow
 */
@property (nonatomic, strong) JPApplePayButton *applePayButton;

/**
 * The PBBA branded button that triggers the PBBA flow
 */
@property (nonatomic, strong) JPPBBAButton *pbbaButton;

/**
 * A method used to apply a theme to the view
 *
 * @param uiConfiguration - the JPUIConfiguration object used to configure the user interface
 */
- (void)applyUIConfiguration:(JPUIConfiguration *)uiConfiguration;

/**
 * A method that configures the header of the payment method screen based on a view model
 */
- (void)configureWithViewModel:(JPPaymentMethodsHeaderModel *)viewModel;

@end
